<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Tilailmoittimen asetukset</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="25"/>
        <source>Reverse the order of items</source>
        <translation>Käänteinen kohteiden järjestys</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="39"/>
        <location filename="../statusnotifierconfiguration.ui" line="49"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Automaattisesti piiloutuva kohde näytetään tämän ajan, kunnes se huomioidaan.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="42"/>
        <source>Attention period:</source>
        <translation>Huomioaika:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="52"/>
        <source> minute(s)</source>
        <translation> minuutti(a)</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="83"/>
        <source>Change visibility of items</source>
        <translation>Määritä kohteiden näkyvyys</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="96"/>
        <source>Item</source>
        <translation>Kohde</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="101"/>
        <source>Visibility</source>
        <translation>Näkyvyys</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always show</source>
        <translation>Näytä aina</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Auto-hide</source>
        <translation>Piilota automaattisesti</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always hide</source>
        <translation>Piilota aina</translation>
    </message>
</context>
</TS>
